@@ -8,9 +8,11 @@
 #' parse formula
 #' A valid formula should have:
 #' - on the left side a list of dependent events
-#' - on the right side a list of names that correspond to effects we have in our pre-defined functions
+#' - on the right side a list of names that correspond to effects
+#'   we have in our pre-defined functions
 #' - parameters for the effects that are coherent with the documentation
-#' on top of this, we parse the formula to the right format for the rest of the estimation
+#'   on top of this, we parse the formula to the right format
+#'   for the rest of the estimation
 #' @param formula a class \code{formula} object that defines the model
 #'
 #' @return a list with parsed values needed in the next steps
@@ -19,13 +21,14 @@
 #' @examples
 #' \donttest{
 #' calls <- structure(
-#'            list(time = 1, sender = "a", receiver = "b", replace = 1),
-#'            class = "dependent.goldfish"
-#'          )
+#'   list(time = 1, sender = "a", receiver = "b", replace = 1),
+#'   class = "dependent.goldfish"
+#' )
 #' callNetwork <- structure(matrix(0, 3, 3), class = "network.goldfish")
-#' 
+#'
 #' parseFormula(
-#'   calls ~ outdeg(callNetwork, type="ego") + indeg(callNetwork, type="alter")
+#'   calls ~ outdeg(callNetwork, type = "ego") +
+#'     indeg(callNetwork, type = "alter")
 #' )
 #' }
 parseFormula <- function(formula, envir = new.env()) {
@@ -33,7 +36,9 @@ parseFormula <- function(formula, envir = new.env()) {
   depName <- getDependentName(formula)
   if (!inherits(get(depName, envir = envir), "dependent.goldfish")) {
     stop("The left hand side of the formula should contain dependent events",
-         " (check the function defineDependentEvents).", call. = FALSE)
+      " (check the function defineDependentEvents).",
+      call. = FALSE
+    )
   }
   # check right side
   rhsNames <- getRHSNames(formula)
@@ -70,9 +75,12 @@ parseFormula <- function(formula, envir = new.env()) {
   mult <- parseMultipleEffects(rhsNames, envir = envir)
   rhsNames <- mult[[1]]
   ignoreRepParameter <- mult[[2]]
-    # check mismatch with default parameter
+  # check mismatch with default parameter
   if (any(unlist(ignoreRepParameter)) && is.null(defaultNetworkName)) {
-    stop("No default network defined, thus ", sQuote("ignoreRep = TRUE"), " effects cannot be used.", call. = FALSE)
+    stop("No default network defined, thus ", dQuote("ignoreRep = TRUE"),
+      " effects cannot be used.",
+      call. = FALSE
+    )
   }
   # check right side: weighted parameter
   weightedParameter <- lapply(rhsNames, function(x) {
@@ -82,16 +90,17 @@ parseFormula <- function(formula, envir = new.env()) {
   # check right side: type = c("ego", "alter")
   typeParameter <- lapply(rhsNames, function(x) {
     v <- getElement(x, "type")
-    ifelse(!is.null(v), v, "")
+    ifelse(!is.null(v), eval(parse(text = v), envir = envir), "")
   })
   # check right side: transformFun & aggregateFun
   getFunName <- function(x, which) {
     v <- getElement(x, which)
     v <- ifelse(!is.null(v), v, "")
-    v <- gsub("['\" ]", "", v)  # replace quotation marks
+    v <- gsub("['\" ]", "", v) # replace quotation marks
     v <- ifelse(
       grepl("function.?\\(", v) || nchar(v) > 12,
-      "userDefined", v) # if it is a function, it is replace by short text
+      "userDefined", v
+    ) # if it is a function, it is replace by short text
   }
   transParameter <- lapply(rhsNames, getFunName, "transformFun")
   aggreParameter <- lapply(rhsNames, getFunName, "aggregateFun")
@@ -127,43 +136,59 @@ parseFormula <- function(formula, envir = new.env()) {
 
 
 # Comparison of two parsed formulas for preprocessingInit
-# throws errors when: dependent events or default network are not the same, when there is righ-censoring
+# throws errors when: dependent events or default network are not the same,
+#  when there is righ-censoring
 # for one and not the other
-# returns: a list of the size of the new formula, with zeros when the effects are new, and with the
-#          the index of the effect in the old formula if the effect was already there
-compareFormulas <- function(oldparsedformula, newparsedformula, model, subModel) {
-
+# returns: a list of the size of the new formula, with zeros when the effects
+#    are new, and with the
+#    the index of the effect in the old formula if the effect was already there
+compareFormulas <- function(
+    oldparsedformula, newparsedformula, model, subModel) {
   # test dependent events and default network
   if (oldparsedformula$depName != newparsedformula$depName) {
-    stop("The dependent events in the formula are not the ones used in",
-         " the preprocessed object given in preprocessingInit.")
+    stop(
+      "The dependent events in the formula are not the ones used in",
+      " the preprocessed object given in preprocessingInit."
+    )
   }
-  if (!identical(oldparsedformula$defaultNetworkName, newparsedformula$defaultNetworkName)) {
-    stop("The default network in the formula is not the one used in",
-         " the preprocessed object given in preprocessingInit.")
+  if (!identical(
+    oldparsedformula$defaultNetworkName,
+    newparsedformula$defaultNetworkName
+  )) {
+    stop(
+      "The default network in the formula is not the one used in",
+      " the preprocessed object given in preprocessingInit."
+    )
   }
   # test the right-censoring
   # for now it's easier to just reject inconsistent formulas, otherwise,
   # we would need go in the details of the RC intervals and updates
   oldhasIntercept <- oldparsedformula$hasIntercept
   newhasIntercept <- newparsedformula$hasIntercept
-  if (model %in% "DyNAM" && subModel %in% c("choice", "choice_coordination") && oldhasIntercept) {
+  if (model %in% "DyNAM" && subModel %in% c("choice", "choice_coordination") &&
+    oldhasIntercept) {
     oldhasIntercept <- FALSE
     newhasIntercept <- FALSE
   }
   if (oldhasIntercept && !newhasIntercept) {
-    stop("The preprocessing for the object in preprocessingInit was not done",
-         " with the right-censored intervals that this formula requires.")
+    stop(
+      "The preprocessing for the object in preprocessingInit was not done",
+      " with the right-censored intervals that this formula requires."
+    )
   }
   if (!oldhasIntercept && newhasIntercept) {
-    stop("The preprocessing for the object in preprocessingInit was done",
-         " with right-censored intervals and this formula does not include those.")
+    stop(
+      "The preprocessing for the object in preprocessingInit was done",
+      " with right-censored intervals and this formula does not include those."
+    )
   }
-  # counters for remembering which of the old effects are found in the new formula
+  # counters for remembering which of the old effects
+  # are found in the new formula
   sizeold <- length(oldparsedformula$rhsNames)
   sizenew <- length(newparsedformula$rhsNames)
   effectsindexes <- rep(0, sizenew)
-  # go through all new effects to check whether they already existed in the old formula
+  # go through all new effects to check whether they already existed
+  # in the old formula
   for (i in seq.int(sizenew)) {
     effectname <- newparsedformula$rhsNames[[i]][[1]]
     effectobject <- newparsedformula$rhsNames[[i]][[2]]
@@ -185,7 +210,9 @@ compareFormulas <- function(oldparsedformula, newparsedformula, model, subModel)
         next
       }
       # 4 check other parameters
-      if (!identical(oldparsedformula$ignoreRepParameter[[j]], effectignorerep)) {
+      if (!identical(
+        oldparsedformula$ignoreRepParameter[[j]], effectignorerep
+      )) {
         next
       }
       if (!identical(oldparsedformula$weightedParameter[[j]], effectweighted)) {
@@ -203,7 +230,8 @@ compareFormulas <- function(oldparsedformula, newparsedformula, model, subModel)
 
 
 # Creation of the different effects with the right parameters
-# in which the first empty parameters are replaced with the ones found in effectInit
+# in which the first empty parameters are replaced with
+# the ones found in effectInit
 # ignores parameters that are not used in the updates computation (parmsIgnore)
 createEffectsFunctions <- function(effectInit, model, subModel,
                                    envir = environment()) {
@@ -216,26 +244,32 @@ createEffectsFunctions <- function(effectInit, model, subModel,
       FUN <- tryCatch(
         eval(parse(text = funText), envir = environment()),
         error = function(e) NULL
-        )
+      )
       # FUN <- NULL
       if (is.null(FUN)) {
-        tryCatch({
-          FUN <- eval(parse(text = x[[1]]), envir = envir)
-        },
-        error = function(e) stop("Unknown effect ", x[[1]]) # ,
-        # finally = warning("Effect ")
+        tryCatch(
+          {
+            FUN <- eval(parse(text = x[[1]]), envir = envir)
+          },
+          error = function(e) stop("Unknown effect ", x[[1]]) # ,
+          # finally = warning("Effect ")
         )
       }
 
       # collect update functions for stat
-      .FUNStat <- utils::getS3method(.statMethod, x[[1]], optional = TRUE,
-                                     envir = environment())
+      .FUNStat <- utils::getS3method(.statMethod, x[[1]],
+        optional = TRUE,
+        envir = environment()
+      )
       if (is.null(.FUNStat)) {
-        .FUNStat <- utils::getS3method(.statMethod, "default", optional = TRUE,
-                                       envir = envir)
+        .FUNStat <- utils::getS3method(.statMethod, "default",
+          optional = TRUE,
+          envir = envir
+        )
       }
 
-      # Update signatures of the effects based on default parameters and above specified parameters
+      # Update signatures of the effects based on default parameters
+      # and above specified parameters
       .signature <- formals(FUN)
       .argsNames <- names(.signature)
       parmsToSet <- x[-1]
@@ -243,12 +277,15 @@ createEffectsFunctions <- function(effectInit, model, subModel,
       if (is.null(names(parmsToSet))) {
         namedParams <- rep(FALSE, length(parmsToSet))
       } else {
-        namedParams <- unlist(lapply(names(parmsToSet), function(v) is.character(v) && v != ""))
+        namedParams <- unlist(lapply(
+          names(parmsToSet),
+          \(v) is.character(v) && v != ""
+        ))
       }
 
       # change parameter type from character to an expression
       nameArg <- parmsToSet[[1]]
-      parmsToSet <- lapply(parmsToSet, function(s) call("eval", parse(text = s)))
+      parmsToSet <- lapply(parmsToSet, \(s) call("eval", parse(text = s)))
 
       # replace named and unnamed parameters
       .argsReplace <- pmatch(names(parmsToSet), .argsNames)
@@ -256,37 +293,50 @@ createEffectsFunctions <- function(effectInit, model, subModel,
       names <- names(parmsToSet)[namedParams]
       # replace named args in formals
       .signature[na.omit(.argsReplace)] <- parmsToSet[!is.na(.argsReplace)]
-      isCondition <- isReservedElementName(.argsNames) & !(.argsNames %in% names)
+      isCondition <- isReservedElementName(.argsNames) &
+        !(.argsNames %in% names)
       .signature[isCondition] <- parmsToSet[!namedParams]
 
       # set isTwoMode parameter, checking if different
       if ("network" %in% .argsNames && "isTwoMode" %in% .argsNames) {
         # cat(x[[1]], is.null(parmsToSet[["isTwoMode"]]))
-        isTwoMode <- length(attr(eval(.signature[["network"]], envir = envir), "nodes")) > 1
+        isTwoMode <- length(attr(
+          eval(.signature[["network"]], envir = envir), "nodes"
+        )) > 1
         if (!is.null(parmsToSet[["isTwoMode"]]) &&
-            eval(parmsToSet[["isTwoMode"]], envir = envir) != isTwoMode) {
+          eval(parmsToSet[["isTwoMode"]], envir = envir) != isTwoMode) {
           warning(
             "The \"isTwoMode\" parameter in effect ",
             x[[1]], " has a different value than",
             " the attributes on network argument '",
-            x[[2]], "'", call. = FALSE, immediate. = TRUE)
+            x[[2]], "'",
+            call. = FALSE, immediate. = TRUE
+          )
         } else if (isTwoMode && is.null(parmsToSet[["isTwoMode"]])) {
           .signature[["isTwoMode"]] <- isTwoMode
-          warning("Setting 'isTwoMode' parameter in effect ", x[[1]],
-                  " to TRUE for network '", x[[2]], "'", call. = FALSE, immediate. = TRUE)
+          warning(
+            "Setting 'isTwoMode' parameter in effect ", x[[1]],
+            " to TRUE for network '", x[[2]], "'",
+            call. = FALSE, immediate. = TRUE
+          )
         }
       }
       # if ("network2" %in% .argsNames && "isTwoMode" %in% .argsNames) {
-      #   isTwoMode <- length(attr(eval(.signature[["network2"]], envir = envir), "nodes")) > 2
-      #   if (!is.null(parmsToSet[["isTwoMode"]]) && eval(parmsToSet[["isTwoMode"]]) != isTwoMode) {
+      #   isTwoMode <- length(attr(
+      #     eval(.signature[["network2"]], envir = envir), "nodes"
+      #   )) > 1
+      #   if (!is.null(parmsToSet[["isTwoMode"]]) &&
+      #   eval(parmsToSet[["isTwoMode"]]) != isTwoMode) {
       #     warning(
-      #       "The 'isTwoMode' parameter in effect ", x[[1]], " has a diferent value than the network argument",
+      #       "The 'isTwoMode' parameter in effect ", x[[1]],
+      #       " has a diferent value than the network argument",
       #       .signature[["network2"]]
       #     )
       #   } else if (isTwoMode) .signature[["isTwoMode"]] <- isTwoMode
       # }
 
-      # if(inherits(.signature, "matrix")) .signature <- apply(.signature, 2, invisible)
+      # if(inherits(.signature, "matrix"))
+      #   .signature <- apply(.signature, 2, invisible)
 
       # Assign signatures with default values to generic functions
       formals(FUN) <- .signature
@@ -303,7 +353,6 @@ createEffectsFunctions <- function(effectInit, model, subModel,
 
 # create new events lists when a window should be applied
 createWindowedEvents <- function(objectEvents, window) {
-
   # create dissolution events
   # - for increment, add the opposite increment
   # - for replace, replace by 0
@@ -347,12 +396,13 @@ extractFormulaTerms <- function(rhs) {
 
 getDependentName <- function(formula) {
   dep <- list(formula[[2]])
-  depName <- unlist(lapply(dep, deparse))
+  unlist(lapply(dep, deparse))
 }
 
 
-getEventsAndObjectsLink <- function(depName, rhsNames, nodes = NULL, nodes2 = NULL,
-                                    envir = environment()) {
+getEventsAndObjectsLink <- function(
+    depName, rhsNames, nodes = NULL, nodes2 = NULL,
+    envir = environment()) {
   # Find objects (irrespective of where they occur)
   objectNames <- getDataObjects(rhsNames)
 
@@ -369,7 +419,7 @@ getEventsAndObjectsLink <- function(depName, rhsNames, nodes = NULL, nodes2 = NU
   )
 
   # replace dependent labels with ids
-  events[[1]] <- sanitizeEvents(events[[1]], nodes, nodes2)
+  events[[1]] <- sanitizeEvents(events[[1]], nodes, nodes2, envir = envir)
   # if(is.character(events[[1]]$sender) && is.character(events[[1]]$receiver)) {
   #   events[[1]]$sender <- match(events[[1]]$sender, get(nodes)$label)
   #   events[[1]]$receiver <- match(events[[1]]$receiver, get(nodes2)$label)
@@ -397,7 +447,9 @@ getEventsAndObjectsLink <- function(depName, rhsNames, nodes = NULL, nodes2 = NU
       )
       evs <- lapply(
         evName,
-        function(x) sanitizeEvents(get(x), nodeSet)
+        function(x) {
+          sanitizeEvents(get(x, envir = envir), nodeSet, envir = envir)
+        }
       )
 
       events <- append(events, evs)
@@ -414,12 +466,14 @@ getEventsAndObjectsLink <- function(depName, rhsNames, nodes = NULL, nodes2 = NU
     if (length(nodesObject) > 1) {
       nodes <- nodesObject[1]
       nodes2 <- nodesObject[2]
-    } else nodes <- nodes2 <- nodesObject
+    } else {
+      nodes <- nodes2 <- nodesObject
+    }
 
     # replace labels with ids
     if (length(evNames) > 0) {
       for (j in seq_along(evs)) {
-        evs[[j]] <- sanitizeEvents(evs[[j]], nodes, nodes2)
+        evs[[j]] <- sanitizeEvents(evs[[j]], nodes, nodes2, envir = envir)
       }
       eventsObjectsLink <- rbind(
         eventsObjectsLink,
@@ -441,8 +495,10 @@ getEventsAndObjectsLink <- function(depName, rhsNames, nodes = NULL, nodes2 = NU
 getEventsEffectsLink <- function(events, rhsNames, eventsObjectsLink) {
   eventsEffectsLink <- matrix(
     data = NA, nrow = length(events), ncol = length(rhsNames),
-    dimnames = list(names(events),
-                    vapply(rhsNames, FUN = "[[", FUN.VALUE = character(1), i = 1))
+    dimnames = list(
+      names(events),
+      vapply(rhsNames, FUN = "[[", FUN.VALUE = character(1), i = 1)
+    )
   )
   for (i in seq_along(rhsNames)) {
     # objects of effect
@@ -486,7 +542,7 @@ parseIntercept <- function(rhsNames) {
   tryCatch(
     v <- as.numeric(rhsNames[[1]][[1]]),
     warning = function(x) {
-      }
+    }
   )
   if (!is.na(v) && v == 1) {
     intercept <- TRUE
@@ -500,7 +556,8 @@ parseIntercept <- function(rhsNames) {
 # Figures out which effect is a multiple effect
 # then finds a network object from the other parameters that this is related to
 # unless a network name is passed to the multiple attribute
-parseMultipleEffects <- function(rhsNames, default = FALSE, envir = environment()) {
+parseMultipleEffects <- function(
+    rhsNames, default = FALSE, envir = environment()) {
   multiple <- list()
   multipleNames <- character(0)
   for (i in seq_along(rhsNames)) {
@@ -508,26 +565,30 @@ parseMultipleEffects <- function(rhsNames, default = FALSE, envir = environment(
     id <- which(names(rhsNames[[i]]) == "ignoreRep")
     multipleParam <- ifelse(length(id) == 1, rhsNames[[i]][[id]], default)
 
-    if (multipleParam %in% c("T", "F", "TRUE", "FALSE"))
+    if (multipleParam %in% c("T", "F", "TRUE", "FALSE")) {
       multipleParam <- as.logical(multipleParam)
+    }
     if (!multipleParam) {
       table <- getDataObjects(rhsNames[i])
       netIds <- vapply(getElementFromDataObjectTable(table, envir = envir),
-                       FUN = inherits,
-                       FUN.VALUE = logical(1),
-                       what = "network.goldfish")
+        FUN = inherits,
+        FUN.VALUE = logical(1),
+        what = "network.goldfish"
+      )
       name <- table[netIds, "name"][1] # take first network
       # apply(getDataObjects(rhsNames)
       # netIds <- sapply(, function(x) "network.goldfish" %in% class(get(x)))
-      # name <- getDataObjects(rhsNames)$object[netIds][[1]]  # get the first network item
+      # # get the first network item
+      # name <- getDataObjects(rhsNames)$object[netIds][[1]]
     }
     if (is.character(multipleParam)) {
       name <- multipleParam
       multipleParam <- FALSE
     }
 
-    if (!is.na(name) && name != "" && !exists(name, envir = envir))
+    if (!is.na(name) && name != "" && !exists(name, envir = envir)) {
       stop("Unknown object in 'ignoreRep' parameter: ", name, call. = FALSE)
+    }
 
     multiple <- append(multiple, multipleParam)
     multipleNames <- c(multipleNames, name)
@@ -545,7 +606,7 @@ parseTimeWindows <- function(rhsNames, envir = new.env()) {
 
   hasWindows <- which(
     vapply(rhsNames, function(x) !is.null(getElement(x, "window")), logical(1))
-    )
+  )
 
   for (i in hasWindows) {
     windowName <- rhsNames[[i]]$window
@@ -555,7 +616,8 @@ parseTimeWindows <- function(rhsNames, envir = new.env()) {
         e$message <- paste(
           "Invalid window parameter for effect ",
           rhsNames[[i]][[1]], " ", rhsNames[[i]][[2]],
-          ":\n", e$message)
+          ":\n", e$message
+        )
         stop(e)
       }
     )
@@ -566,18 +628,21 @@ parseTimeWindows <- function(rhsNames, envir = new.env()) {
 
     # support for lubridate object classes for date operations
     if (inherits(window, c("Period", "Duration")) &&
-        "lubridate" %in% attr(attr(window, "class"), "package")) {
+      "lubridate" %in% attr(attr(window, "class"), "package")) {
       if (!isValidName) {
         windowName <- gsub("\\s", "", as.character(window))
-        if (inherits(window, "Duration"))
-          windowName <- gsub("^(\\d+s)\\s*(\\(.+\\))$", "\\1",
-                             as.character(window))
+        if (inherits(window, "Duration")) {
+          windowName <- gsub(
+            "^(\\d+s)\\s*(\\(.+\\))$", "\\1",
+            as.character(window)
+          )
         }
+      }
     } else if (inherits(window, "character")) {
       if (!isValidName) windowName <- gsub(" ", "", window)
 
       if (!is.numeric(window) &&
-          !grepl("^\\d+ (sec|min|hour|day|week|month|year)", window)) {
+        !grepl("^\\d+ (sec|min|hour|day|week|month|year)", window)) {
         stop(
           "The window effect specified with the effect ", rhsNames[[i]][[1]],
           " ", rhsNames[[i]][[2]], " is not in the form 'number unit'\n",
@@ -602,19 +667,21 @@ parseTimeWindows <- function(rhsNames, envir = new.env()) {
       if (grepl("week", window)) {
         window <- as.numeric(strsplit(window, " ")[[1]][1]) * 604800
       }
-      if (grepl("month", window)) {
-        window <- as.numeric(strsplit(window, " ")[[1]][1]) * 2629800 # lubridate approximation
+      if (grepl("month", window)) { # lubridate approximation
+        window <- as.numeric(strsplit(window, " ")[[1]][1]) * 2629800
       }
-      if (grepl("year", window)) {
-        window <- as.numeric(strsplit(window, " ")[[1]][1]) * 31557600 # lubridate approximation
+      if (grepl("year", window)) { # lubridate approximation
+        window <- as.numeric(strsplit(window, " ")[[1]][1]) * 31557600
       }
     } else if (is.numeric(window)) { # check numeric type
 
-      if (window < 0)
+      if (window < 0) {
         stop(
           "The window specified with the effect ",
           rhsNames[[i]][[1]], " ", rhsNames[[i]][[2]],
-          " is not a positive numeric value")
+          " is not a positive numeric value"
+        )
+      }
     }
 
 
@@ -630,13 +697,14 @@ parseTimeWindows <- function(rhsNames, envir = new.env()) {
     # newRhs[[2]] <- paste(rhsNames[[i]][[2]], window, sep="_")
     # rhsNames[[length(rhsNames)+1]] <- newRhs
     rhsNames[[i]][[2]] <- paste(rhsNames[[i]][[2]],
-                                windowName,
-                                sep = "_"
+      windowName,
+      sep = "_"
     )
 
 
     if (isAttribute) {
-      # get nodes & attribute, add new windowed attribute, get related events to be windowed later
+      # get nodes & attribute, add new windowed attribute,
+      # get related events to be windowed later
       nameNodes <- objects$nodeset
       nodes <- get(nameNodes, envir = envir)
       attribute <- objects$attribute
@@ -648,8 +716,8 @@ parseTimeWindows <- function(rhsNames, envir = new.env()) {
       allDynamicAttributes <- attr(nodes, "dynamicAttributes")
       allEvents <- allEvents[allDynamicAttributes == attribute]
     } else {
-
-      # get network, create windowed network, get related events to be windowed later
+      # get network, create windowed network, get related events
+      # to be windowed later
       network <- get(name, envir = envir)
 
       newNetwork <- matrix(0, nrow = nrow(network), ncol = ncol(network))
