@@ -1,6 +1,8 @@
 #' @importFrom utils packageVersion packageDescription
 .onAttach <- function(libname, pkgname) {
-  if (!interactive()) return()
+  if (!interactive()) {
+    return()
+  }
   base::packageStartupMessage(
     "  <\")))><  The goldfish package in R\n\n",
     pkgname, ": version ", utils::packageVersion("goldfish"), " ",
@@ -10,14 +12,14 @@
 
   # packageStartupMessage(
   # "Please cite as:\nChristoph Stadtfeld and James Hollway (2018). \"goldfish:
-  #  Statistical network models for dynamic network data\". R package version ", 
+  #  Statistical network models for dynamic network data\". R package version ",
   #  packageVersion("goldfish"),
   #   ", www.social-networks.ethz.ch/research/goldfish.html.\n")
 }
 
-# Whenever you use C++ code in your package, you need to clean up 
+# Whenever you use C++ code in your package, you need to clean up
 # after yourself when your package is unloaded.
-# Do this by writing a .onUnload() function that unloads the DLL: 
+# Do this by writing a .onUnload() function that unloads the DLL:
 # (http://r-pkgs.had.co.nz/src.html)
 .onUnload <- function(libpath) {
   library.dynam.unload("goldfish", libpath)
